<?php
namespace Bushelpowered\Api\Aggregator\Payments\V1\Request;
        
class CreatePaymentDetailsRequest 
{
    /** @var \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentOrigin $origin */
    public \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentOrigin $origin;
    /** @var \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentType $paymentType */
    public \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentType $paymentType;
    /** @var string $fundingSourceId The id of the funding source to be used. If the origin of this payment is bushel then this should be an id of a wallet funding source. If the origin is card, then this should be the id of the card record.*/
    public string $fundingSourceId;
    /** @var string $startingAmount The starting dollar amount of the payment before surcharges*/
    public string $startingAmount;
    /** @var null|string $comments Allows a user to say something that they want to about this payment. Required for oneTime payments.*/
    public ?string $comments = null;
    /** @var \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentCurrency $currency */
    public \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentCurrency $currency;
    /** @var null|string $processOn The date when the payment should be processed in the format of ISO 8601. The time should be at noon on the day the user selects. Leave this null if the payment should be processed immediately. ex: 2025-07-02T12:00:00-05:00*/
    public ?string $processOn = null;
    /** @var \Bushelpowered\Api\Aggregator\Payments\V1\Model\PaymentAttachment[]|null $attachments This will be required if paymentType is invoice or settlement*/
    public ?array $attachments = null;

    /**
     * @param  \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentOrigin  $origin 
     * @param  \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentType  $paymentType 
     * @param  string  $fundingSourceId The id of the funding source to be used. If the origin of this payment is bushel then this should be an id of a wallet funding source. If the origin is card, then this should be the id of the card record.
     * @param  string  $startingAmount The starting dollar amount of the payment before surcharges
     * @param  null|string  $comments Allows a user to say something that they want to about this payment. Required for oneTime payments.
     * @param  \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentCurrency  $currency 
     * @param  null|string  $processOn The date when the payment should be processed in the format of ISO 8601. The time should be at noon on the day the user selects. Leave this null if the payment should be processed immediately. ex: 2025-07-02T12:00:00-05:00
     * @param  \Bushelpowered\Api\Aggregator\Payments\V1\Model\PaymentAttachment[]|null  $attachments This will be required if paymentType is invoice or settlement
     */
    public function __construct(\Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentOrigin $origin, \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentType $paymentType, string $fundingSourceId, string $startingAmount, ?string $comments, \Bushelpowered\Api\Aggregator\Payments\V1\Enums\PaymentCurrency $currency, ?string $processOn, ?array $attachments)
    {
        $this->origin = $origin;
        $this->paymentType = $paymentType;
        $this->fundingSourceId = $fundingSourceId;
        $this->startingAmount = $startingAmount;
        $this->comments = $comments;
        $this->currency = $currency;
        $this->processOn = $processOn;
        $this->attachments = $attachments;
    }
    

}