<?php
namespace Bushelpowered\Api\Crm\V1\Response;
        
class CustomersResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $name The name of the customer, editable*/
    public string $name;
    /** @var \Bushelpowered\Api\Crm\V1\Response\CustomerAddressResponse[] $addresses */
    public array $addresses;
    /** @var \Bushelpowered\Api\Crm\V1\Response\ContactInformationResponse[] $emails */
    public array $emails;
    /** @var \Bushelpowered\Api\Crm\V1\Response\ContactInformationResponse[] $phones */
    public array $phones;
    /** @var string[] $accountIds List of account ids for the customer*/
    public array $accountIds;
    /** @var string[] $assignedStaffUsers The staff user IDs for the customer*/
    public array $assignedStaffUsers;
    /** @var null|\Bushelpowered\Api\Crm\V1\Response\DemographicResponse $demographic */
    public ?\Bushelpowered\Api\Crm\V1\Response\DemographicResponse $demographic = null;
    /** @var null|string $lastActivityAt Last activity date-time for the customer of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $lastActivityAt = null;
    /** @var null|string $lastActivityBy Last activity by user UUID for the customer*/
    public ?string $lastActivityBy = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $name The name of the customer, editable
     * @param  \Bushelpowered\Api\Crm\V1\Response\CustomerAddressResponse[]  $addresses 
     * @param  \Bushelpowered\Api\Crm\V1\Response\ContactInformationResponse[]  $emails 
     * @param  \Bushelpowered\Api\Crm\V1\Response\ContactInformationResponse[]  $phones 
     * @param  string[]  $accountIds List of account ids for the customer
     * @param  string[]  $assignedStaffUsers The staff user IDs for the customer
     * @param  null|\Bushelpowered\Api\Crm\V1\Response\DemographicResponse  $demographic 
     * @param  null|string  $lastActivityAt Last activity date-time for the customer of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $lastActivityBy Last activity by user UUID for the customer
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $name, array $addresses, array $emails, array $phones, array $accountIds, array $assignedStaffUsers, ?\Bushelpowered\Api\Crm\V1\Response\DemographicResponse $demographic, ?string $lastActivityAt, ?string $lastActivityBy, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->name = $name;
        $this->addresses = $addresses;
        $this->emails = $emails;
        $this->phones = $phones;
        $this->accountIds = $accountIds;
        $this->assignedStaffUsers = $assignedStaffUsers;
        $this->demographic = $demographic;
        $this->lastActivityAt = $lastActivityAt;
        $this->lastActivityBy = $lastActivityBy;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}