<?php
namespace Bushelpowered\Api\Data\Analytics\V1\Request;
        
class ContractsFilters implements \Bushelpowered\Api\Common\HasCreatedAtFilter
{
    /** @var string[]|null $ids Contract id in list*/
    public ?array $ids = null;
    /** @var string[]|null $tenantIds Tenant id in list*/
    public ?array $tenantIds = null;
    /** @var null|string $displayId Contract display id, partial match*/
    public ?string $displayId = null;
    /** @var string[]|null $accountIds Account id in list*/
    public ?array $accountIds = null;
    /** @var string[]|null $commodityIds Commodity id in list*/
    public ?array $commodityIds = null;
    /** @var string[]|null $locationIds Contract location id OR delivery location id in list*/
    public ?array $locationIds = null;
    /** @var null|int $cropYearEqualOrAfter Crop year is equal or after (inclusive)*/
    public ?int $cropYearEqualOrAfter = null;
    /** @var null|int $cropYearBefore Crop year is before (exclusive)*/
    public ?int $cropYearBefore = null;
    /** @var null|bool $isClosed Contract status is closed*/
    public ?bool $isClosed = null;
    /** @var null|string $createdAtEqualOrAfter Created at is equal or after (inclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $createdAtEqualOrAfter = null;
    /** @var null|string $createdAtBefore Created at is before (exclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $createdAtBefore = null;

    /**
     * @param  string[]|null  $ids Contract id in list
     * @param  string[]|null  $tenantIds Tenant id in list
     * @param  null|string  $displayId Contract display id, partial match
     * @param  string[]|null  $accountIds Account id in list
     * @param  string[]|null  $commodityIds Commodity id in list
     * @param  string[]|null  $locationIds Contract location id OR delivery location id in list
     * @param  null|int  $cropYearEqualOrAfter Crop year is equal or after (inclusive)
     * @param  null|int  $cropYearBefore Crop year is before (exclusive)
     * @param  null|bool  $isClosed Contract status is closed
     * @param  null|string  $createdAtEqualOrAfter Created at is equal or after (inclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $createdAtBefore Created at is before (exclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(?array $ids, ?array $tenantIds, ?string $displayId, ?array $accountIds, ?array $commodityIds, ?array $locationIds, ?int $cropYearEqualOrAfter, ?int $cropYearBefore, ?bool $isClosed, ?string $createdAtEqualOrAfter, ?string $createdAtBefore)
    {
        $this->ids = $ids;
        $this->tenantIds = $tenantIds;
        $this->displayId = $displayId;
        $this->accountIds = $accountIds;
        $this->commodityIds = $commodityIds;
        $this->locationIds = $locationIds;
        $this->cropYearEqualOrAfter = $cropYearEqualOrAfter;
        $this->cropYearBefore = $cropYearBefore;
        $this->isClosed = $isClosed;
        $this->createdAtEqualOrAfter = $createdAtEqualOrAfter;
        $this->createdAtBefore = $createdAtBefore;
    }
    
    /**
     * @return null|string Created at is equal or after (inclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAtEqualOrAfter(): ?string
    {
        return $this->createdAtEqualOrAfter;
    }
    /**
     * @return null|string Created at is before (exclusive) of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAtBefore(): ?string
    {
        return $this->createdAtBefore;
    }
}