<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class ContractRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var string $sourceAccountId The source account identifier.*/
    public string $sourceAccountId;
    /** @var string $accountIntegrationId The account integration identifier.*/
    public string $accountIntegrationId;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationIntegrationId The location integration identifier.*/
    public ?string $locationIntegrationId = null;
    /** @var null|string $sourceCommodityId The source commodity identifier.*/
    public ?string $sourceCommodityId = null;
    /** @var null|string $commodityIntegrationId The commodity integration identifier.*/
    public ?string $commodityIntegrationId = null;
    /** @var null|string $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.*/
    public ?string $sourceCropYear = null;
    /** @var null|string $sourceDisplayId The grower-friendly identifier for the contract. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.*/
    public ?string $sourceDisplayId = null;
    /** @var null|bool $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.*/
    public ?bool $sourceIsClosed = null;
    /** @var null|float $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.*/
    public ?float $sourceQuantityCanceled = null;
    /** @var null|float $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.*/
    public ?float $sourceQuantityContracted = null;
    /** @var null|float $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.*/
    public ?float $sourceQuantityDelivered = null;
    /** @var null|string $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.*/
    public ?string $sourceQuantityUom = null;
    /** @var null|string $sourceType The type of the contract. Typically, the more generic of the two type fields, Sales or Purchase.*/
    public ?string $sourceType = null;
    /** @var null|string $sourceSubtype The subtype of the contract. Typically, the more specific of the two type fields representing a "product". e.g. Basis, Hedged to Arrive, Delayed Price, etc.*/
    public ?string $sourceSubtype = null;
    /** @var null|string $sourceDeferPayDate The defer pay date. The agreement between parties to make a payment at a later date. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeferPayDate = null;
    /** @var null|string $sourceSignatureStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.*/
    public ?string $sourceSignatureStatus = null;
    /** @var null|string $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!*/
    public ?string $sourceComments = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  string  $sourceAccountId The source account identifier.
     * @param  string  $accountIntegrationId The account integration identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationIntegrationId The location integration identifier.
     * @param  null|string  $sourceCommodityId The source commodity identifier.
     * @param  null|string  $commodityIntegrationId The commodity integration identifier.
     * @param  null|string  $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.
     * @param  null|string  $sourceDisplayId The grower-friendly identifier for the contract. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.
     * @param  null|bool  $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.
     * @param  null|float  $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.
     * @param  null|float  $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.
     * @param  null|float  $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.
     * @param  null|string  $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.
     * @param  null|string  $sourceType The type of the contract. Typically, the more generic of the two type fields, Sales or Purchase.
     * @param  null|string  $sourceSubtype The subtype of the contract. Typically, the more specific of the two type fields representing a "product". e.g. Basis, Hedged to Arrive, Delayed Price, etc.
     * @param  null|string  $sourceDeferPayDate The defer pay date. The agreement between parties to make a payment at a later date. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceSignatureStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.
     * @param  null|string  $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, string $sourceAccountId, string $accountIntegrationId, ?string $sourceLocationId, ?string $locationIntegrationId, ?string $sourceCommodityId, ?string $commodityIntegrationId, ?string $sourceCropYear, ?string $sourceDisplayId, ?bool $sourceIsClosed, ?float $sourceQuantityCanceled, ?float $sourceQuantityContracted, ?float $sourceQuantityDelivered, ?string $sourceQuantityUom, ?string $sourceType, ?string $sourceSubtype, ?string $sourceDeferPayDate, ?string $sourceSignatureStatus, ?string $sourceComments, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->accountIntegrationId = $accountIntegrationId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationIntegrationId = $locationIntegrationId;
        $this->sourceCommodityId = $sourceCommodityId;
        $this->commodityIntegrationId = $commodityIntegrationId;
        $this->sourceCropYear = $sourceCropYear;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->sourceIsClosed = $sourceIsClosed;
        $this->sourceQuantityCanceled = $sourceQuantityCanceled;
        $this->sourceQuantityContracted = $sourceQuantityContracted;
        $this->sourceQuantityDelivered = $sourceQuantityDelivered;
        $this->sourceQuantityUom = $sourceQuantityUom;
        $this->sourceType = $sourceType;
        $this->sourceSubtype = $sourceSubtype;
        $this->sourceDeferPayDate = $sourceDeferPayDate;
        $this->sourceSignatureStatus = $sourceSignatureStatus;
        $this->sourceComments = $sourceComments;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return string The source account identifier.
     */
    public function getSourceAccountId(): string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The source location identifier.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}