<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class ContractStandard implements \Bushelpowered\Api\Common\Event\StandardRecord, \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $entityRevisionId The revision idempotency key.*/
    public string $entityRevisionId;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var string $sourceAccountId The source account identifier.*/
    public string $sourceAccountId;
    /** @var string $accountId The account identifier.*/
    public string $accountId;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationId The location identifier.*/
    public ?string $locationId = null;
    /** @var null|string $sourceCommodityId The source commodity identifier.*/
    public ?string $sourceCommodityId = null;
    /** @var null|string $commodityId The commodity identifier.*/
    public ?string $commodityId = null;
    /** @var null|string $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.*/
    public ?string $sourceCropYear = null;
    /** @var null|string $sourceDisplayId The grower-friendly identifier for the contract. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.*/
    public ?string $sourceDisplayId = null;
    /** @var null|bool $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.*/
    public ?bool $sourceIsClosed = null;
    /** @var null|float $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.*/
    public ?float $sourceQuantityCanceled = null;
    /** @var null|float $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.*/
    public ?float $sourceQuantityContracted = null;
    /** @var null|float $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.*/
    public ?float $sourceQuantityDelivered = null;
    /** @var null|string $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.*/
    public ?string $sourceQuantityUom = null;
    /** @var null|string $quantityUom Standardized unit of measure.*/
    public ?string $quantityUom = null;
    /** @var null|string $sourceType The type of the contract. Typically, the more generic of the two type fields, Sales or Purchase.*/
    public ?string $sourceType = null;
    /** @var null|string $sourceSubtype The subtype of the contract. Typically, the more specific of the two type fields representing a "product". e.g. Basis, Hedged to Arrive, Delayed Price, etc.*/
    public ?string $sourceSubtype = null;
    /** @var null|string $sourceDeferPayDate The defer pay date. The agreement between parties to make a payment at a later date. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeferPayDate = null;
    /** @var null|string $sourceSignatureStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.*/
    public ?string $sourceSignatureStatus = null;
    /** @var null|string $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!*/
    public ?string $sourceComments = null;
    /** @var \Bushelpowered\Api\Grain\Contracts\V1\Model\PricingLineStandard[] $pricingLines */
    public array $pricingLines;
    /** @var string $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var null|string $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $entityRevisionId The revision idempotency key.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  string  $sourceAccountId The source account identifier.
     * @param  string  $accountId The account identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationId The location identifier.
     * @param  null|string  $sourceCommodityId The source commodity identifier.
     * @param  null|string  $commodityId The commodity identifier.
     * @param  null|string  $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.
     * @param  null|string  $sourceDisplayId The grower-friendly identifier for the contract. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.
     * @param  null|bool  $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.
     * @param  null|float  $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.
     * @param  null|float  $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.
     * @param  null|float  $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.
     * @param  null|string  $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.
     * @param  null|string  $quantityUom Standardized unit of measure.
     * @param  null|string  $sourceType The type of the contract. Typically, the more generic of the two type fields, Sales or Purchase.
     * @param  null|string  $sourceSubtype The subtype of the contract. Typically, the more specific of the two type fields representing a "product". e.g. Basis, Hedged to Arrive, Delayed Price, etc.
     * @param  null|string  $sourceDeferPayDate The defer pay date. The agreement between parties to make a payment at a later date. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceSignatureStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.
     * @param  null|string  $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!
     * @param  \Bushelpowered\Api\Grain\Contracts\V1\Model\PricingLineStandard[]  $pricingLines 
     * @param  string  $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $entityRevisionId, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, string $sourceAccountId, string $accountId, ?string $sourceLocationId, ?string $locationId, ?string $sourceCommodityId, ?string $commodityId, ?string $sourceCropYear, ?string $sourceDisplayId, ?bool $sourceIsClosed, ?float $sourceQuantityCanceled, ?float $sourceQuantityContracted, ?float $sourceQuantityDelivered, ?string $sourceQuantityUom, ?string $quantityUom, ?string $sourceType, ?string $sourceSubtype, ?string $sourceDeferPayDate, ?string $sourceSignatureStatus, ?string $sourceComments, array $pricingLines, string $updatedAt, string $createdAt, ?string $deletedAt, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt)
    {
        $this->id = $id;
        $this->entityRevisionId = $entityRevisionId;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->accountId = $accountId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationId = $locationId;
        $this->sourceCommodityId = $sourceCommodityId;
        $this->commodityId = $commodityId;
        $this->sourceCropYear = $sourceCropYear;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->sourceIsClosed = $sourceIsClosed;
        $this->sourceQuantityCanceled = $sourceQuantityCanceled;
        $this->sourceQuantityContracted = $sourceQuantityContracted;
        $this->sourceQuantityDelivered = $sourceQuantityDelivered;
        $this->sourceQuantityUom = $sourceQuantityUom;
        $this->quantityUom = $quantityUom;
        $this->sourceType = $sourceType;
        $this->sourceSubtype = $sourceSubtype;
        $this->sourceDeferPayDate = $sourceDeferPayDate;
        $this->sourceSignatureStatus = $sourceSignatureStatus;
        $this->sourceComments = $sourceComments;
        $this->pricingLines = $pricingLines;
        $this->updatedAt = $updatedAt;
        $this->createdAt = $createdAt;
        $this->deletedAt = $deletedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The primary unique identifier.
     */
    public function getId(): string
    {
        return $this->id;
    }
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return string The account identifier.
     */
    public function getAccountId(): string
    {
        return $this->accountId;
    }
    /**
     * @return null|string The location identifier.
     */
    public function getLocationId(): ?string
    {
        return $this->locationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}