<?php
namespace Bushelpowered\Api\Iam\Keycloak\V1;

use \Bushelpowered\Api\Iam\Keycloak\V1\Request\InviteUserRequest;
use \Bushelpowered\Api\Iam\Keycloak\V1\Response\InviteUserResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\ConstraintViolation;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bidl\Php\Core\Builtins\UnknownError;

class InviteUser 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    /**
     * @deprecated use request instead.
     */
    public function call(InviteUserRequest $request, $headers): InviteUserResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | UnknownError
    {
         return $this->client->call('api/iam/keycloak/v1/InviteUser', $request, $this->getWrapper(), $headers);
    }
    
    public function request(InviteUserRequest $request, InviteUserMetadata $hasHeaders): InviteUserResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | UnknownError
    {
         return $this->client->call('api/iam/keycloak/v1/InviteUser', $request, $this->getWrapper(), $hasHeaders->getMetaData());
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var InviteUserResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.iam.keycloak.v1#InviteUserSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Iam\Keycloak\V1\Response\InviteUserResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#BadRequest':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#ConstraintViolation':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\ConstraintViolation::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}