<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Request;
        
class AutomatedCreateDocumentRequest implements \Bushelpowered\Api\Trade\Esign\V1\Request\EncodedPdf
{
    /** @var string $id A unique identifier for this Contract*/
    public string $id;
    /** @var null|string $name The name of the Contract, shown to the grower user.*/
    public ?string $name = null;
    /** @var null|string $version A version number for the contract. If id matches an existing contract, having a different version will create an amendment.*/
    public ?string $version = null;
    /** @var string $senderUserEmail The email of the bushel staff user that is sending this contract.*/
    public string $senderUserEmail;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[] $actions The signature boxes to be placed on the document.*/
    public array $actions;
    /** @var string $file The PDF of the document base64 encoded.*/
    public string $file;

    /**
     * @param  string  $id A unique identifier for this Contract
     * @param  null|string  $name The name of the Contract, shown to the grower user.
     * @param  null|string  $version A version number for the contract. If id matches an existing contract, having a different version will create an amendment.
     * @param  string  $senderUserEmail The email of the bushel staff user that is sending this contract.
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[]  $actions The signature boxes to be placed on the document.
     * @param  string  $file The PDF of the document base64 encoded.
     */
    public function __construct(string $id, ?string $name, ?string $version, string $senderUserEmail, array $actions, string $file)
    {
        $this->id = $id;
        $this->name = $name;
        $this->version = $version;
        $this->senderUserEmail = $senderUserEmail;
        $this->actions = $actions;
        $this->file = $file;
    }
    
    /**
     * @return string The PDF of the document base64 encoded.
     */
    public function getFile(): string
    {
        return $this->file;
    }
}